Attribute VB_Name = "MFileOpCallback"
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
''
'' Name:         MFileOpCallback
'' Filename:     MFileOpCallback.bas
'' Project:      VB+ IProgressDialog sample
'' Author:       Mattias Sjgren (mattiass@hem.passagen.se)
''               http://hem.spray.se/mattias.sjogren/
''
'' Description:  IProgressDialog sample progress callback module
''
'' Dependencies: None
''
''
'' Copyright 2000, Mattias Sjgren
''
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''

Option Explicit

'''''''''''''''''''''
'''   Constants   '''
'''''''''''''''''''''

' CopyProgressRoutine return values
Private Const PROGRESS_CONTINUE = 0
Private Const PROGRESS_CANCEL = 1


'
' Note #1:  A generic CopyProgressRoutine function should be declared
'
'           ..., ByVal lpData As Long) As Long
'
'           But in this case lpData is always a ProgressDialog object reference,
'           so it's easier to type it like that directly.
'
' Note #2:  Moving a file within the same partition doesn't require any data to
'           actually be moved, so the callback procedure will not be called.
'
Public Function CopyProgressRoutine(ByVal TotalFileSize As Currency, ByVal TotalBytesTransferred As Currency, _
                                    ByVal StreamSize As Currency, ByVal StreamBytesTransferred As Currency, _
                                    ByVal dwStreamNumber As Long, ByVal dwCallbackReason As Long, _
                                    ByVal hSourceFile As Long, ByVal hDestinationFile As Long, _
                                    ByVal lpData As ProgressDialog) As Long

  If lpData.HasUserCancelled Then
    ' Cancel was pressed - stop the file operation
    CopyProgressRoutine = PROGRESS_CANCEL
  Else
    ' update progress dialog, then continue
    lpData.SetProgress64 TotalBytesTransferred, TotalFileSize
    CopyProgressRoutine = PROGRESS_CONTINUE
  End If
  
  ' Currency variables are 64 bit integers, scaled down by 10000. To display correct size,
  ' you have to multiply by 10000
  'Debug.Print TotalBytesTransferred * 10000# & " of " & _
  '            TotalFileSize * 10000# & " bytes transferred."

End Function
 

